@@ -11,9 +11,6 @@
 #include "generalsettings.h"
 #include "global.h"
 #include "haruna-version.h"
-#include "lockmanager.h"
-#include "mediaplayer2.h"
-#include "mediaplayer2player.h"
 #include "mousesettings.h"
 #include "mpvitem.h"
 #include "playbacksettings.h"
@@ -32,7 +29,6 @@
 #include <QCoreApplication>
 #include <QDesktopServices>
 #include <QDir>
-#include <QDBusConnection>
 #include <QFileInfo>
 #include <QFontDatabase>
 #include <QGuiApplication>
@@ -98,14 +94,6 @@ Application::Application(int &argc, char **argv, const QString &applicationName)
     QObject::connect(appEventFilter, &ApplicationEventFilter::applicationMouseLeave,
                      this, &Application::qmlApplicationMouseLeave);
 
-    // register mpris dbus service
-    QString mspris2Name(QStringLiteral("org.mpris.MediaPlayer2.haruna"));
-    QDBusConnection::sessionBus().registerService(mspris2Name);
-    QDBusConnection::sessionBus().registerObject(QStringLiteral("/org/mpris/MediaPlayer2"),
-                                                 this, QDBusConnection::ExportAdaptors);
-    // org.mpris.MediaPlayer2 mpris2 interface
-    new MediaPlayer2(this);
-
     if (GeneralSettings::guiStyle() != QStringLiteral("System")) {
         QApplication::setStyle(GeneralSettings::guiStyle());
     }
@@ -207,34 +195,18 @@ void Application::registerQmlTypes()
 
 void Application::setupQmlSettingsTypes()
 {
-    auto audioProvider = [](QQmlEngine *, QJSEngine *) -> QObject * { return AudioSettings::self(); };
-    qmlRegisterSingletonType<AudioSettings>("org.kde.haruna", 1, 0, "AudioSettings", audioProvider);
-
-    auto generalProvider = [](QQmlEngine *, QJSEngine *) -> QObject * { return GeneralSettings::self(); };
-    qmlRegisterSingletonType<GeneralSettings>("org.kde.haruna", 1, 0, "GeneralSettings", generalProvider);
-
-    auto mouseProvider = [](QQmlEngine *, QJSEngine *) -> QObject * { return MouseSettings::self(); };
-    qmlRegisterSingletonType<MouseSettings>("org.kde.haruna", 1, 0, "MouseSettings", mouseProvider);
-
-    auto playbackProvider = [](QQmlEngine *, QJSEngine *) -> QObject * { return PlaybackSettings::self(); };
-    qmlRegisterSingletonType<PlaybackSettings>("org.kde.haruna", 1, 0, "PlaybackSettings", playbackProvider);
-
-    auto playlistProvider = [](QQmlEngine *, QJSEngine *) -> QObject * { return PlaylistSettings::self(); };
-    qmlRegisterSingletonType<PlaylistSettings>("org.kde.haruna", 1, 0, "PlaylistSettings", playlistProvider);
-
-    auto subtitlesProvider = [](QQmlEngine *, QJSEngine *) -> QObject * { return SubtitlesSettings::self(); };
-    qmlRegisterSingletonType<SubtitlesSettings>("org.kde.haruna", 1, 0, "SubtitlesSettings", subtitlesProvider);
-
-    auto videoProvider = [](QQmlEngine *, QJSEngine *) -> QObject * { return VideoSettings::self(); };
-    qmlRegisterSingletonType<VideoSettings>("org.kde.haruna", 1, 0, "VideoSettings", videoProvider);
+    qmlRegisterSingletonInstance("org.kde.haruna", 1, 0, "AudioSettings",     AudioSettings::self());
+    qmlRegisterSingletonInstance("org.kde.haruna", 1, 0, "GeneralSettings",   GeneralSettings::self());
+    qmlRegisterSingletonInstance("org.kde.haruna", 1, 0, "MouseSettings",     MouseSettings::self());
+    qmlRegisterSingletonInstance("org.kde.haruna", 1, 0, "PlaybackSettings",  PlaybackSettings::self());
+    qmlRegisterSingletonInstance("org.kde.haruna", 1, 0, "PlaylistSettings",  PlaylistSettings::self());
+    qmlRegisterSingletonInstance("org.kde.haruna", 1, 0, "SubtitlesSettings", SubtitlesSettings::self());
+    qmlRegisterSingletonInstance("org.kde.haruna", 1, 0, "VideoSettings",     VideoSettings::self());
 }
 
 void Application::setupQmlContextProperties()
 {
-    std::unique_ptr<LockManager> lockManager = std::make_unique<LockManager>();
-    m_engine->rootContext()->setContextProperty("lockManager", lockManager.release());
     m_engine->rootContext()->setContextProperty("app", this);
-    m_engine->rootContext()->setContextProperty("mediaPlayer2Player", new MediaPlayer2Player(this));
     m_engine->rootContext()->setContextProperty("appActions", new QQmlPropertyMap);
     m_engine->rootContext()->setContextObject(new KLocalizedContext(this));
     m_engine->rootContext()->setContextProperty("harunaAboutData",
@@ -370,16 +342,10 @@ QString Application::getFileContent(const QString &file)
     return content;
 }
 
-QString Application::mimeType(const QString &file)
+QString Application::mimeType(const QUrl &url)
 {
-    QMimeDatabase db;
-    QMimeType mimeType;
-    if(KFileItem(file).isSlow()) {
-        mimeType = db.mimeTypeForFile(file, QMimeDatabase::MatchExtension);
-    } else {
-        mimeType = db.mimeTypeForFile(file);
-    }
-    return mimeType.name();
+    KFileItem fileItem(url, KFileItem::NormalMimeTypeDetermination);
+    return fileItem.mimetype();
 }
 
 QStringList Application::availableGuiStyles()
