@@ -23,7 +23,7 @@ MpvCore::MpvCore(QQuickItem *parent)
     if (mpv_initialize(m_mpv) < 0) {
         qFatal("could not initialize mpv context");
     }
-    mpv_set_wakeup_callback(m_mpv, MpvItem::mpvEvents, this);
+    mpv_set_wakeup_callback(m_mpv, MpvCore::mpvEvents, this);
 }
 
 MpvCore::~MpvCore()
