@@ -7,8 +7,6 @@
 #ifndef MPVOBJECT_H
 #define MPVOBJECT_H
 
-#include <QtQuick/QQuickFramebufferObject>
-
 #include "mpvcore.h"
 #include "playlistmodel.h"
 #include "tracksmodel.h"
@@ -141,6 +139,11 @@ signals:
     void youtubePlaylistLoaded();
     void syncConfigValue(QString path, QString group, QString key, QVariant value);
 
+    // signals used for mpris
+    void playNext();
+    void playPrevious();
+    void openUri(const QString &uri);
+
 private:
     TracksModel *audioTracksModel() const;
     TracksModel *subtitleTracksModel() const;
